##  Modifying Completion Weights
Using weights of 0 or 1 keeps the completion calculation simple and clear. This approach is generally enough for most situations and makes it easier to understand the results. However, admins can modify the weights as needed to highlight the importance of specific fields.
As an admin, you can adjust the weights for each fact sheet type by following these steps:
  1. In the fact sheet configuration, select the fact sheet header to open the settings panel on the right.
  2. In the settings panel, go to the Completion weights tab, indicated by the weighing balance icon.
  3. Make your changes and click Review changes.
  4. On the next page, click Apply to save your modifications.


![Modifying the Completion Weights in the Fact Sheet Configuration](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c5ebe7a441014902eb14890f369c0_LowRes.png)
Modifying the Completion Weights in the Fact Sheet Configuration
**Tip**
Best Practice: It's a good practice to hide unused sections or subsections to simplify the experience for stakeholders of fact sheets. Any stored data in the hidden sections will remain intact and can be made visible anytime. These sections will still be accessible via API even when hidden.
To hide a section or subsection, select the section or subsection and toggle the Visible switch off in the Configuration tab of the right side panel.
